@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.5.2-0
+# Application Name - Health Check V0.5.2-1
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -112,11 +112,19 @@ class Ui_MainWindow(object):
         
         # Setup and draw the button
         self.pushButton_hw = QtGui.QPushButton(self.tab)
-        self.pushButton_hw.setGeometry(QtCore.QRect(0, 310, 800, 51))
+        self.pushButton_hw.setGeometry(QtCore.QRect(0, 310, 500, 51))
         self.pushButton_hw.setObjectName("pushButton_hw")
-        self.pushButton_hw.setText("Update All")
+        self.pushButton_hw.setText("Update Tab")
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
         QtCore.QObject.connect(self.pushButton_hw, QtCore.SIGNAL('clicked()'), self.updateTab1)
+
+        # Setup and draw the button
+        self.pushButton_a1 = QtGui.QPushButton(self.tab)
+        self.pushButton_a1.setGeometry(QtCore.QRect(500, 310, 300, 51))
+        self.pushButton_a1.setObjectName("pushButton_a1")
+        self.pushButton_a1.setText("Update All")
+        # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
+        QtCore.QObject.connect(self.pushButton_a1, QtCore.SIGNAL('clicked()'), self.updateAll)
                 
         # Draw the Tab Contents
         self.tabWidget.addTab(self.tab, "")
@@ -135,12 +143,20 @@ class Ui_MainWindow(object):
 
         # Setup and draw the button
         self.pushButton_com = QtGui.QPushButton(self.tab_2)
-        self.pushButton_com.setGeometry(QtCore.QRect(0, 310, 800, 51))
+        self.pushButton_com.setGeometry(QtCore.QRect(0, 310, 500, 51))
         self.pushButton_com.setObjectName("pushButton_com")
-        self.pushButton_com.setText("Update All")
+        self.pushButton_com.setText("Update Tab")
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
         QtCore.QObject.connect(self.pushButton_com, QtCore.SIGNAL('clicked()'), self.updateTab2)
 
+        # Setup and draw the button
+        self.pushButton_a2 = QtGui.QPushButton(self.tab_2)
+        self.pushButton_a2.setGeometry(QtCore.QRect(500, 310, 300, 51))
+        self.pushButton_a2.setObjectName("pushButton_a2_2")
+        self.pushButton_a2.setText("Update All")
+        # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
+        QtCore.QObject.connect(self.pushButton_a2, QtCore.SIGNAL('clicked()'), self.updateAll)
+
         # Show the tab and draw contents
         self.tabWidget.addTab(self.tab_2, "")
 
@@ -192,14 +208,14 @@ class Ui_MainWindow(object):
 
         # Setup and draw the button
         self.pushButton_reboot = QtGui.QPushButton(self.tab_4)
-        self.pushButton_reboot.setGeometry(QtCore.QRect(10, 312, 391, 41))
+        self.pushButton_reboot.setGeometry(QtCore.QRect(10, 280, 391, 71))
         self.pushButton_reboot.setObjectName("pushButton_reboot")
         self.pushButton_reboot.setText("System Reboot")
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
         QtCore.QObject.connect(self.pushButton_reboot, QtCore.SIGNAL('clicked()'), self.reboot_sys)
 
         self.pushButton_von = QtGui.QPushButton(self.tab_4)
-        self.pushButton_von.setGeometry(QtCore.QRect(10, 100, 391, 61))
+        self.pushButton_von.setGeometry(QtCore.QRect(10, 200, 391, 71))
         self.pushButton_von.setObjectName("pushButton_von")
         self.pushButton_von.setText("Test Vibrate")
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
@@ -217,7 +233,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.5.2-0 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
+        self.textBrowser.setText (" Health Check V 0.5.2-1 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -285,11 +301,17 @@ class Ui_MainWindow(object):
         
 
     def reboot_sys(self):
-       
-        # Close b - the greatly named variable - as i want to use it again! (Well close or declare it!)
-        b = None
-        b = os.popen('run-standalone.sh dbus-send --system --type=method_call --dest="com.nokia.dsme" --print-reply "/com/nokia/dsme/request" com.nokia.dsme.request.req_reboot')
-        b.close ()
+        import gtk
+        self.CloseDialog = QtGui.QMessageBox.question(None, "Time for a Reboot!","Do you really want to reboot?",QtGui.QMessageBox.Yes|QtGui.QMessageBox.No,QtGui.QMessageBox.No)
+        if self.CloseDialog == QtGui.QMessageBox.Yes:
+            
+            b = None
+            b = os.popen('run-standalone.sh dbus-send --system --type=method_call --dest="com.nokia.dsme" --print-reply "/com/nokia/dsme/request" com.nokia.dsme.request.req_reboot')
+            b.close ()
+        elif self.CloseDialog == QtGui.QMessageBox.No:
+            print "User pressed 'Cancel' button"
+            
+        
         
         
 # Funtion - update the front camera image
@@ -531,9 +553,15 @@ class Ui_MainWindow(object):
         
 # Funtion - update tab.... Originally to update tab1, but using it to collate the functions
 # It has the commented out message boxes, will work on this later
+    def updateAll(self):
+        self.updateTab1()
+        self.updateTab2()
+    
     def updateTab1(self):
+        import hildon
         self.listWidget.clear()
         self.pushButton_hw.setEnabled(False)
+        self.pushButton_a1.setEnabled(False)
         self.pushButton_hw.setText(".")  
         Thread(target=self.updaterootfs()).start()
         self.pushButton_hw.setText("..")
@@ -549,20 +577,33 @@ class Ui_MainWindow(object):
         self.pushButton_hw.setText(".......")
         Thread(target=self.updateBatt()).start()
         self.pushButton_hw.setText("........")
-        self.pushButton_hw.setText("Update All")
+        self.pushButton_hw.setText("Update Tab")
         self.pushButton_hw.setEnabled(True)
+        self.pushButton_a1.setEnabled(True)
         self.listWidget.sortItems()
+        bus = dbus.SessionBus()
+        proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
+        interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
+        interface.Notify('HealthCheck', 0, '/usr/share/icons/hicolor/scalable/hildon/healthcheck.png', 'System Tab', 'Finished Loading', [], {}, 2000)
+
+
 
     def updateTab2(self):
         self.listWidget2.clear()
         self.pushButton_com.setEnabled(False)
+        self.pushButton_a2.setEnabled(False)
         self.pushButton_com.setText("...")
         Thread(target=self.updateGPS()).start()
         self.pushButton_com.setText(".....")
         Thread(target=self.Cellular()).start()
-        self.pushButton_com.setText("Update All")
+        self.pushButton_com.setText("Update Tab")
         self.pushButton_com.setEnabled(True)
+        self.pushButton_a2.setEnabled(True)
         self.listWidget2.sortItems()
+        bus = dbus.SessionBus()
+        proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
+        interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
+        interface.Notify('HealthCheck', 0, '/usr/share/icons/hicolor/scalable/hildon/healthcheck.png/healthcheck.png', 'Comms Tab', 'Finished Loading', [], {}, 2000)
 
     def updateTab3(self):
         self.pushButton_cam.setEnabled(False)
@@ -580,7 +621,7 @@ class Ui_MainWindow(object):
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.2-0", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.1-0", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
